@@ -25,6 +25,7 @@ OC.L10N.register(
     "Copy link" : "Copiar enlace",
     "Edit" : "Editar",
     "Delete" : "Borrar",
+    "Calendars" : "Calendarios",
     "New calendar" : "Nuevo calendario",
     "New calendar with task list" : "Nuevo calendario con listado de tareas",
     "Copied link" : "Link copiado",
@@ -34,6 +35,8 @@ OC.L10N.register(
     "Restore" : "Restaurar",
     "Delete permanently" : "Borrar permanentemente",
     "Empty trash bin" : "Vaciar la papelera",
+    "Deck" : "Deck",
+    "Hidden" : "Oculto",
     "Copy internal link" : "Copiar enlace interno",
     "Share link" : "Compartir link",
     "Copy public link" : "Copiar link publico",
@@ -66,6 +69,7 @@ OC.L10N.register(
     "Delete file" : "Borrar archivo",
     "Choose a file to add as attachment" : "Seleccione el archivo a agregar como adjunto",
     "Available" : "Disponible",
+    "Not available" : "No disponible",
     "Done" : "Terminado",
     "Unknown" : "Desconocido",
     "Accept" : "Aceptar",
