@@ -12,6 +12,7 @@ OC.L10N.register(
     "No upcoming events" : "Tulekul sündmuseid pole",
     "Calendar" : "Kalender",
     "Confirm" : "Kinnita",
+    "Description:" : "Kirjeldus:",
     "Date:" : "Kuupäev:",
     "Where:" : "Kus:",
     "Comment:" : "Kommentaar:",
@@ -38,6 +39,7 @@ OC.L10N.register(
     "Add new" : "Lisa uus",
     "Untitled calendar" : "Nimetu kalender",
     "Edit calendar" : "Muuda kalendrit",
+    "Calendars" : "Kalendrid",
     "New calendar" : "Uus kalender",
     "Export" : "Ekspordi",
     "Trash bin" : "Prügikast",
@@ -46,6 +48,7 @@ OC.L10N.register(
     "Restore" : "Taasta",
     "Delete permanently" : "Kustuta jäädavalt",
     "Empty trash bin" : "Tühjenda prügikast",
+    "Hidden" : "Peidetud",
     "Internal link" : "Sisemine link",
     "Copy internal link" : "Kopeeri sisemine link",
     "Share link" : "Jaga link",
