@@ -72,6 +72,7 @@ OC.L10N.register(
     "An error occurred, unable to change visibility of the calendar." : "Terjadi galat, tidak dapat mengubah visibilitas kalender.",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Batal berbagi kalender dalam {countdown} detik"],
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Menghapus kalender dalam {countdown} detik"],
+    "Calendars" : "Kalender",
     "New calendar" : "Kalender baru",
     "Name for new calendar" : "Nama untuk kalender baru",
     "Creating calendar …" : "Membuat kalender …",
@@ -103,6 +104,8 @@ OC.L10N.register(
     "Could not restore calendar or event" : "Tidak dapat memulihkan kalender atau acara",
     "Do you really want to empty the trash bin?" : "Apakah Anda benar-benar ingin mengosongkan keranjang sampah?",
     "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Item dalam keranjang sampah dihapus setelah {numDays} hari"],
+    "Deck" : "Longgok",
+    "Hidden" : "Sembunyi",
     "Could not update calendar order." : "Tidak dapat membarui urutan kalender.",
     "Share link" : "Bagikan tautan",
     "Copy public link" : "Salin tautan publik",
@@ -204,6 +207,7 @@ OC.L10N.register(
     "Busy" : "Sibuk",
     "Out of office" : "Keluar kantor",
     "Unknown" : "Tidak diketahui",
+    "Room name" : "Nama ruang",
     "Accept" : "Terima",
     "Decline" : "Tolak",
     "Tentative" : "Tentatif",
