@@ -8,6 +8,7 @@ OC.L10N.register(
     "Cheers!" : "წარმატებები!",
     "Calendar" : "კალენდარი",
     "Confirm" : "დადასტურება",
+    "Description:" : "აღწერა:",
     "Where:" : "სად:",
     "Today" : "დღეს",
     "Day" : "დღე",
@@ -24,6 +25,8 @@ OC.L10N.register(
     "Deleted" : "გაუქმდა",
     "Restore" : "აღდგენა",
     "Delete permanently" : "სამუდამოდ წაშლა",
+    "Deck" : "დასტა",
+    "Hidden" : "უჩინარი",
     "Share link" : "ბმულის გაზიარება",
     "can edit" : "შეგიძლია შეცვლა",
     "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
@@ -54,6 +57,7 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
     "Done" : "დასრულდა",
     "Unknown" : "ამოუცნობი",
+    "Room name" : "ოთახის სახელი",
     "Accept" : "მიღება",
     "Decline" : "ურაყოფა",
     "Tentative" : "საცდელი",
