@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Calendar" : "ປະຕິທິນ",
     "Confirm" : "ຢືນຢັນ",
-    "Personal" : "ສ່ວນບຸກຄົນ",
     "Today" : "ມື້ນີ້",
     "Copy link" : "ສຳເນົາລິງ",
     "Edit" : "ແກ້ໄຂ",
@@ -27,14 +26,11 @@ OC.L10N.register(
     "Available" : "ມີຢູ່",
     "Not available" : "ບໍ່ມີ",
     "Unknown" : "ບໍ່ຮູ້",
-    "Send email" : "ສົ່ງອີເມວ",
     "never" : "ບໍ່ເຄີຍ",
-    "More" : "ເພີ່ມເຕີມ",
+    "Personal" : "ສ່ວນບຸກຄົນ",
     "Details" : "ລາຍລະອຽດ",
     "Close" : "ປິດ",
     "Daily" : "ລາຍວັນ",
-    "Weekly" : "ອາທິດ",
-    "Review" : "ເບິ່ງຄຶນ",
-    "Mail" : "ຈົດໝາຍ"
+    "Weekly" : "ອາທິດ"
 },
 "nplurals=1; plural=0;");
