@@ -9,6 +9,7 @@ OC.L10N.register(
     "Calendar" : "Kalendar",
     "Appointments" : "Takime",
     "Confirm" : "Konfirmo",
+    "Description:" : "Përshkrimi:",
     "Where:" : "Ku:",
     "Today" : "Sot",
     "Day" : "Ditë",
@@ -25,6 +26,8 @@ OC.L10N.register(
     "Deleted" : "E fshirë",
     "Restore" : "Rikthe",
     "Delete permanently" : "Fshije përgjithmonë",
+    "Deck" : "Shto paisjen U2F",
+    "Hidden" : "I fshehur",
     "Copy internal link" : "Kopjoni lidhjen e brendshme",
     "Share link" : "Ndani lidhjen",
     "can edit" : "mund të përpunojnë",
@@ -57,6 +60,7 @@ OC.L10N.register(
     "Available" : "i disponueshëm",
     "Done" : "U bë",
     "Unknown" : "I/E panjohur",
+    "Room name" : "Emri i dhomës",
     "Accept" : "Prano",
     "Decline" : "Refuzo",
     "Tentative" : "Tentativë",
