@@ -10,14 +10,18 @@ OC.L10N.register(
     "Cheers!" : "ไชโย!",
     "Calendar" : "ปฏิทิน",
     "Confirm" : "ยืนยัน",
+    "Previous year" : "ปีที่แล้ว",
+    "Next year" : "ปีหน้า",
     "Today" : "วันนี้",
     "Day" : "วัน",
     "Week" : "สัปดาห์",
     "Month" : "เดือน",
+    "Year" : "ปี",
     "Preview" : "ตัวอย่าง",
     "Copy link" : "คัดลอกลิงก์",
     "Edit" : "แก้ไข",
     "Delete" : "ลบ",
+    "Calendars" : "ปฏิทิน",
     "New calendar" : "สร้างปฏิทินใหม่",
     "Export" : "ส่งออก",
     "Name" : "ชื่อ",
@@ -25,6 +29,7 @@ OC.L10N.register(
     "Restore" : "คืนค่า",
     "Delete permanently" : "ลบแบบถาวร",
     "Empty trash bin" : "ล้างข้อมูลในถังขยะ",
+    "Hidden" : "ซ่อนอยู่",
     "Share link" : "แชร์ลิงก์",
     "can edit" : "สามารถแก้ไข",
     "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
@@ -32,8 +37,10 @@ OC.L10N.register(
     "Filename" : "ชื่อไฟล์",
     "Cancel" : "ยกเลิก",
     "Automatic" : "อัตโนมัติ",
+    "Year view" : "มุมมองรายปี",
     "List view" : "มุมมองแบบรายการ",
     "Actions" : "การกระทำ",
+    "_{duration} year_::_{duration} years_" : ["{duration}ปี"],
     "Location" : "ตำแหน่ง",
     "Description" : "คำอธิบาย",
     "to" : "ถึง",
@@ -71,6 +78,8 @@ OC.L10N.register(
     "Week {number} of {year}" : "สัปดาห์ที่ {number} ของปี {year}",
     "Daily" : "รายวัน",
     "Weekly" : "รายสัปดาห์",
+    "Monthly" : "ทุก ๆ เดือน",
+    "Yearly" : "ทุก ๆ ปี",
     "Other" : "อื่น ๆ",
     "When shared show full event" : "เมื่อแชร์จะแสดงกิจกรรมเต็ม",
     "When shared show only busy" : "เมื่อแชร์จะแสดงเฉพาะไม่ว่าง",
